@@ -184,21 +184,22 @@ getmaskpar <- function(OK, D, m, sessnum, unmash, nmash) {
 #--------------------------------------------------------------------------------
 getchat <- function (cc0, nc, n.distrib, group, usge, pmixn, pID,
                      cellsize, gkhk, pi.density, sumD,  PIA0, binomN, MRdata, miscparm, 
-                     nsim, grain) {
+                     nsim, grain,ncores) {
     kk <- nrow(usge)
     ss <- ncol(usge)
     mm <- nrow(pi.density)
     ngroup <- length(levels(group))   ## uNUSED
     ## note: should pass pi.mask as pi.density for known distribution all-sighting
     temp <- sightingchatcpp (
-        mm, 
-        nc, 
-        cc0, 
-        grain, 
-        nsim,        ## number of replicate simulations for chat 
+        as.integer(mm), 
+        as.integer(nc), 
+        as.integer(cc0), 
+        as.integer(grain), 
+        as.integer(ncores),
+        as.integer(nsim),        ## number of replicate simulations for chat 
         as.integer(MRdata$sightmodel),  ## 5 allsighting known n0, 6 allsighting unknown n0
-        sumD,
-        cellsize,
+        as.double(sumD),
+        as.double(cellsize),
         as.integer(n.distrib),
         as.integer(binomN),      ## detector -2 multi, -1 proximity 0 Poisson count 1 Binomial from usage, 2...etc. 
         as.integer(MRdata$markocc), 
@@ -222,13 +223,17 @@ getchat <- function (cc0, nc, n.distrib, group, usge, pmixn, pID,
     return (sumchat)
 }
 
-makegk <- function(dettype, detectfn, trps, mask, details, sessnum, noneuc, D, miscparm, realparval) {
-    if (is.null(details$grain)) details$grain <- 1   ## 2020-05-16 for backward compatibility
+makegk <- function(dettype, detectfn, trps, mask, details, sessnum, noneuc, D, miscparm, realparval, grain, ncores) {
     ## precompute gk, hk for point detectors
     if (all(dettype %in% c(0,1,2,5,8,13))) {
         distmat2 <- getuserdist(trps, mask, details$userdist, sessnum, noneuc, D, miscparm, detectfn == 20)
-        gkhk <- makegkPointcpp (as.integer(detectfn), as.integer(details$grain),
-                                as.matrix(realparval), as.matrix(distmat2), miscparm)
+        gkhk <- makegkPointcpp (
+            as.integer(detectfn), 
+            as.integer(grain),
+            as.integer(ncores),
+            as.matrix(realparval), 
+            as.matrix(distmat2), 
+            miscparm)
         if (any(dettype==8)) {   ## capped adjustment Not checked 2019-09-08
             gkhk <- cappedgkhkcpp (
                 as.integer(nrow(realparval)),
@@ -247,9 +252,15 @@ makegk <- function(dettype, detectfn, trps, mask, details, sessnum, noneuc, D, m
         dimension <- (dettype[1] %in% c(3,6)) + 1   ## 1 = 1D, 2 = 2D
         convexpolygon <- is.null(details$convexpolygon) || details$convexpolygon
         gkhk <- makegkPolygoncpp (
-            as.integer(detectfn), as.integer(dimension), as.logical(convexpolygon), 
-            as.integer(details$grain), as.matrix(realparval), as.integer(cumk),
-            as.matrix(trps), as.matrix(mask))
+            as.integer(detectfn), 
+            as.integer(dimension), 
+            as.logical(convexpolygon), 
+            as.integer(grain), 
+            as.integer(ncores), 
+            as.matrix(realparval), 
+            as.integer(cumk),
+            as.matrix(trps), 
+            as.matrix(mask))
     }
     gkhk
 }
