@@ -93,7 +93,14 @@ NumericMatrix xydist2cpp (
 // customised dpois 
 double gpois (int count, double lambda, int uselog)
 {
-    if (count == 0) {
+    double x;
+    if ((count < 0) || (count>0 && lambda <= 0)) {
+        if (uselog) 
+            return(NAN);
+        else 
+            return(0);
+    }
+    else if (count == 0) {
         if (uselog)
             return (-lambda);
         else
@@ -102,7 +109,7 @@ double gpois (int count, double lambda, int uselog)
     else {
         // return (R::dpois(count, lambda, uselog));
         boost::math::poisson_distribution<> pois(lambda);
-        double x = boost::math::pdf(pois, count);
+        x = boost::math::pdf(pois, count);
         if (uselog) x = log(x);
         return (x);
     }
@@ -114,16 +121,25 @@ double gbinom(int count, int size, double p, int uselog)
 {
     double x, q;
     int i;
-    if (count == 0) {
+    if ((count < 0) || (count > 0 && p <= 0)) {
+        x = 0;
+    }
+    else if (count == 0) {
         q = 1 - p;
         x = q;
         for (i=1; i< size; i++) x *= q;
     }
     else {
+        // x = R::dbinom(count, size, p, 0);
         boost::math::binomial_distribution<> bin(size, p);
         x = boost::math::pdf(bin, count);
     }
-    if (uselog) x = log(x);
+    if (uselog) {
+        if (x <= 0) 
+            x = NAN;
+        else
+            x = log(x);
+    }
     return (x);   
 }
 //--------------------------------------------------------------------------
@@ -217,7 +233,8 @@ double zrcpp (double r, int detectfn, NumericVector par)
         else if (detectfn == 19) {  // hazard variable power
             return (exp(- pow(r /par(1), par(2))));
         }
-        else (Rcpp::stop("unknown or invalid detection function in gxy"));
+        else 
+            return (NAN);  //Rcpp::stop("unknown or invalid detection function in gxy"));
     }
 }
 
@@ -921,8 +938,8 @@ int firstkcpp (const int n,
         wxi = i4(n,0,k,x,nc,ss,nk);
     }
     while ((PIA[wxi] == 0) && (k<nk));
-    if (k>=nk)  Rcpp::stop ("no detector used on first occasion? error in getpmix"); 
-    return(k);
+    if (k>=nk) return (NAN);  // Rcpp::stop ("no detector used on first occasion? error in getpmix"); 
+    else return(k);
 }
 //=============================================================
 
@@ -1262,6 +1279,7 @@ double pski ( int binomN,
               double g,
               double pI) {
     
+    double lambda;
     double result = 1.0;
     
     if (binomN == -1) {                              // binary proximity detectors : Bernoulli
@@ -1274,14 +1292,17 @@ double pski ( int binomN,
             result = 1 - g*pI;
     }
     else if (binomN == 0) {                          // count detectors : Poisson 
-        double tmp = Tski * g * pI;
-        //if (tmp<0) result = NAN;
-        if (count == 0) 
-            result = exp(-tmp);            // routinely apply Tsk adjustment to cum. hazard 
+        lambda = Tski * g * pI;
+        if ((count < 0) || (count>0 && lambda<=0)) {         
+            result = 0;
+        }
+        else if (count == 0) {
+            result = exp(-lambda);            // routinely apply Tsk adjustment to cum. hazard 
+        }
         else {
-            // result = R::dpois(count, Tski * g * pI, 0); 
-            boost::math::poisson_distribution<> pois(tmp);
-            result = boost::math::pdf(pois,count); 
+            //result = R::dpois(count, Tski * g * pI, 0); 
+            boost::math::poisson_distribution<> pois(lambda);
+            result = boost::math::pdf(pois,count);
         }
     }
     else if (binomN == 1) {                          // count detectors : Binomial, size from Tsk
@@ -1293,7 +1314,7 @@ double pski ( int binomN,
         }
         result = gbinom (count, binomN, g*pI, 0);
     }
-    else Rcpp::stop("binomN < -1 not allowed");  // code multi -2 separately
+    else result = NAN; // Rcpp::stop("binomN < -1 not allowed");  // code multi -2 separately
     
     return (result);
 }
